@@ -4,7 +4,11 @@
 #define SKALIBS_POSIXPLZ_H
 
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <regex.h>
+
 #include <skalibs/gccattributes.h>
+#include <skalibs/functypes.h>
 
 
  /*
@@ -14,17 +18,6 @@
 extern char **environ ;
 
 
- /*
-    Stuff that _is_ POSIX, but some OSes still don't have it.
-    openat() et al. should be here, but they're impossible to
-    emulate correctly, and I don't want an app using openat()
-    to think it has safe POSIX semantics when it doesn't :/
-    EPROTO et al. should be here, but ugh ifdef forests.
- */
-
-extern size_t strnlen (char const *, size_t) gccattr_pure ;
-
-
  /*
     Non-POSIX functions that some OSes provide and others don't.
     setgroups() isn't included because it's its own kind of broken.
@@ -44,4 +37,19 @@ extern void unlink_void (char const *) ;
 extern pid_t doublefork (void) ;
 extern int touch (char const *) ;
 
+extern int mkfiletemp (char *, createfunc_t_ref, mode_t, void *) ;
+extern int mklinktemp (char const *, char *, linkfunc_t_ref) ;
+extern int mkptemp (char *) ;
+extern int mkltemp (char const *, char *) ;
+extern int mkhtemp (char const *, char *) ;
+extern int mkctemp (char *, mode_t, dev_t) ;
+extern int mkbtemp (char *, mode_t, dev_t) ;
+
+
+ /*
+    Wrappers around functions that should be specified better.
+ */
+
+#define skalibs_regcomp(re, s, flags) regcomp(re, (s)[0] ? (s) : ".*", flags)
+
 #endif
