@@ -4,7 +4,7 @@
 
 int timestamp_r (char *s, tain_t *stamp)
 {
-  if (!tain_sysclock(stamp)) return 0 ;
+  if (!tain_wallclock_read(stamp)) return 0 ;
   timestamp_fmt(s, stamp) ;
   return 1 ;
 }
