@@ -1,17 +1,15 @@
 /* ISC license. */
 
 #include <skalibs/nonposix.h>
+
 #include <sys/socket.h>
 #include <errno.h>
+
+#include <skalibs/posixishard.h>
 #include <skalibs/error.h>
 #include <skalibs/iopause.h>
 #include <skalibs/unix-timed.h>
 
- /* For MacOS, that still doesn't know what POSIX says */
-#ifndef MSG_NOSIGNAL
-#define MSG_NOSIGNAL 0
-#endif
-
 int ipc_timed_send (int fd, char const *s, size_t len, tain_t const *deadline, tain_t *stamp)
 {
   iopause_fd x = { .fd = fd, .events = IOPAUSE_WRITE, .revents = 0 } ;
