@@ -1,7 +1,5 @@
 #!/bin/sh -e
 
-#!/bin/sh -e
-
 sysdeps="$1"
 bits="$2"
 dfmt="$3"
@@ -9,16 +7,24 @@ ofmt="$4"
 xfmt="$5"
 bfmt="$6"
 
+gen_bits() {
+  sed -e "s/@BITS@/$1/g; s/@DFMT@/$2/g; s/@OFMT@/$3/g; s/@XFMT@/$4/g; s/@BFMT@/$5/g;" < src/headers/bits-template
+}
+
 tools/gen-types-internal.sh "" "" "$bits" < src/headers/bits-header
 
-if test "$bits" = 64 && grep -qF 'uint64t: no' "$sysdeps" ; then
-  if grep -qF 'sizeofulong: 8' "$sysdeps" ; then
-    cat src/headers/uint64-ulong64
-  else
-    cat src/headers/uint64-noulong64
+if test "$bits" = 64 ; then
+  cat src/headers/uint64-defs
+  if grep -qF 'uint64t: no' "$sysdeps" ; then
+    if grep -qF 'sizeofulong: 8' "$sysdeps" ; then
+      cat src/headers/uint64-ulong64
+    else
+      cat src/headers/uint64-noulong64
+    fi
+    cat src/headers/uint64-macros
   fi
 else
-  tools/gen-types-internal.sh "" "" "$bits" < src/headers/bits-stdint
+  cat src/headers/uint64-include
 fi
 
 if grep -qF 'endianness: little' < "$sysdeps" ; then
@@ -29,6 +35,7 @@ else
   echo 'Error ! Unsupported endianness' 1>&2
   ./crash
 fi
+
 tools/gen-types-internal.sh "" "" "$bits" < src/headers/bits-${endian}endian
-tools/gen-bits-internal.sh "$bits" "$dfmt" "$ofmt" "$xfmt" "$bfmt"
+gen_bits "$bits" "$dfmt" "$ofmt" "$xfmt" "$bfmt"
 exec tools/gen-types-internal.sh "" "" "$bits" < src/headers/bits-footer
